﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing;

namespace WindowsFormsApplication1
{
  public static class MyUtils
  {
    static internal System.IO.Stream GetResource(string name)
    {
      return System.Reflection.Assembly.GetExecutingAssembly().GetManifestResourceStream(name);
    }

    static internal Image GetBitmapResource(string name)
    {
      System.IO.Stream stream = GetResource(name);
      return stream == null ? null : new System.Drawing.Bitmap(stream);
    }
  }

  public class MyToolStrip : ToolStrip
  {
    private System.ComponentModel.IContainer components;
    private System.Windows.Forms.ToolStripButton bNormal = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripSeparator bSeparator = new System.Windows.Forms.ToolStripSeparator();
    private System.Windows.Forms.ToolStripButton bRotate = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bMove = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bZoom = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bDepth = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bView3D = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bEdit = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bPrint = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bCopy = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bExport = new System.Windows.Forms.ToolStripButton();
    private System.Windows.Forms.ToolStripButton bLabel = new System.Windows.Forms.ToolStripButton();

    public MyToolStrip()
      : base()
    {
      AddToolBarButtons(CreateStandardItems());
      InitializeComponent();
      this.ItemClicked += new ToolStripItemClickedEventHandler(MyToolStrip_ItemClicked);
    }

    private void MyToolStrip_ItemClicked(object sender, ToolStripItemClickedEventArgs e)
    {
      if (e.ClickedItem is ToolStripButton)
      {
        DoItemChecked(e.ClickedItem as ToolStripButton);
      }
    }

    private void DoItemChecked(ToolStripButton button)
    {
      MessageBox.Show(button.Tag.ToString());
    }

    private void InitializeComponent()
    {
      this.components = new System.ComponentModel.Container();
    }

    private void AddToolBarButtons(System.Windows.Forms.ToolStripItem[] tItems)
    {
      base.Items.AddRange(tItems);
    }

    private ToolStripItem[] CreateStandardItems()
    {
      this.ImageScalingSize = new Size(new Point(16, 16));

      this.ImageList = new ImageList();
      this.ImageList.TransparentColor = System.Drawing.Color.Lime;
      this.ImageList.Images.Add("Copy", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Copy16x16.bmp"));
      this.ImageList.Images.Add("Depth", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Depth16x16.bmp"));
      this.ImageList.Images.Add("Edit", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Edit16x16.bmp"));
      this.ImageList.Images.Add("Export", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Export16x16.bmp"));
      this.ImageList.Images.Add("Move", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Move16x16.bmp"));
      this.ImageList.Images.Add("Normal", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Normal16x16.bmp"));
      this.ImageList.Images.Add("Print", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Print16x16.bmp"));
      this.ImageList.Images.Add("Rotate", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Rotate16x16.bmp"));
      this.ImageList.Images.Add("View3D", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.View3D16x16.bmp"));
      this.ImageList.Images.Add("Zoom", MyUtils.GetBitmapResource("WindowsFormsApplication1.Images.Zoom16x16.bmp"));
      this.bNormal.ImageKey = "Normal";

      this.bNormal.Checked = true;
      this.bNormal.ToolTipText = "CommanMsgNormal";
      this.bNormal.CheckOnClick = true;
      this.bNormal.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bNormal.Tag = "bNormal";

      this.bSeparator.Tag = "bSeparator";
      this.bRotate.ImageKey = "Rotate";
      this.bRotate.CheckOnClick = true;
      this.bRotate.ToolTipText = "CommanMsgRotate";
      this.bRotate.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bRotate.Tag = "bRotate";

      this.bMove.ImageKey = "Move";
      this.bMove.CheckOnClick = true;
      this.bMove.ToolTipText = "CommanMsgMove";
      this.bMove.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bMove.Tag = "bMove";

      this.bZoom.ImageKey = "Zoom";
      this.bZoom.CheckOnClick = true;
      this.bZoom.ToolTipText = "CommanMsgZoom";
      this.bZoom.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bZoom.Tag = "bZoom";

      this.bDepth.ImageKey = "Depth";
      this.bDepth.CheckOnClick = true;
      this.bDepth.ToolTipText = "CommanMsgDepth";
      this.bDepth.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bDepth.Tag = "bDepth";

      this.bView3D.ImageKey = "View3D";
      this.bView3D.CheckOnClick = false;
      this.bView3D.ToolTipText = "CommanMsg3D";
      this.bView3D.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bView3D.Tag = "bView3D";

      this.bEdit.ImageKey = "Edit";
      this.bEdit.CheckOnClick = true;
      this.bEdit.ToolTipText = "CommanMsgEdit";
      this.bEdit.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bEdit.Tag = "bEdit";

      this.bPrint.ImageKey = "Print";
      this.bPrint.CheckOnClick = true;
      this.bPrint.ToolTipText = "CommanMsgPrint";
      this.bPrint.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bPrint.Tag = "bPrint";

      this.bCopy.ImageKey = "Copy";
      this.bCopy.CheckOnClick = true;
      this.bCopy.ToolTipText = "CommanMsgCopy";
      this.bCopy.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bCopy.Tag = "bCopy";

      this.bExport.ImageKey = "Export";
      this.bExport.CheckOnClick = true;
      this.bExport.ToolTipText = "CommanMsgSave";
      this.bExport.DisplayStyle = ToolStripItemDisplayStyle.Image;
      this.bExport.Tag = "bExport";

      this.bLabel.DisplayStyle = ToolStripItemDisplayStyle.Text;
      this.bLabel.Tag = "bLabel";

      return new System.Windows.Forms.ToolStripItem[] {	this.bNormal,
                                                        this.bSeparator,
                                                        this.bRotate,
                                                        this.bMove,
                                                        this.bZoom,
                                                        this.bDepth,
                                                        this.bView3D,
                                                        this.bSeparator,
                                                        this.bEdit,
                                                        this.bPrint,
                                                        this.bCopy,
                                                        this.bExport,
																												this.bLabel																														 
                                                      };
    }

  }
}
